@@ -1,11 +1,9 @@
 package ExtUtils::ModuleMaker::Interactive;
-#$Id$
 use strict;
 use warnings;
 BEGIN {
     use base qw( ExtUtils::ModuleMaker );
-    use vars qw ( $VERSION ); 
-    $VERSION = 0.56;
+    our $VERSION = "0.63";
 }
 use Carp;
 use Data::Dumper;
@@ -358,6 +356,7 @@ sub Main_Menu {
             : $string =~ s|##name##||;
         $string =~ s|##abstract##|$MOD->{ABSTRACT}|;
         $string =~ s|##license##|$MOD->{LICENSE}|;
+        $MOD->{BUILD_SYSTEM} = 'Module::Build' if $MOD->{USE_MODULE_BUILD};
         $string =~ s|##build##|$MOD->{BUILD_SYSTEM}|;
     
         my $response = Question_User( $string, 'menu' );
@@ -630,7 +629,7 @@ James E Keenan.  CPANID:  JKEENAN.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005, 2017 James E. Keenan.  All rights reserved.
+Copyright (c) 2005, 2018 James E. Keenan.  All rights reserved.
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
 
